from pymongo import MongoClient
from .blog_client import BlogPost

class BlogRepository:

    def __init__(self, mongo_connection, blogId):
        self.mongo_connect = mongo_connection
        self.client = MongoClient(mongo_connection)
        self.musicblogs_database = self.client.musicblogs
        self.blogId = blogId
        self.posts_collection = self.musicblogs_database['posts.' + blogId]
        self.posts_in_blog = self.posts_collection.find()
        self.posts_map = \
            {p['postId']: BlogPost(
                postId=p['postId'], title=p['title'], videoId=p['videoId'], content=p['content'],
                labels=p.get('labels', 0),
                url=p.get('url', ''),
                amara_embed=p.get('amara_embed', '')
            ) for p in self.posts_in_blog
            }

        self.postids = set(self.posts_map.keys())

    def update_blog_post(self, blog_post):
        if not blog_post:
            return

        if not hasattr(blog_post, "postId"):
            return
        if (blog_post.postId in self.postids):
            self.postids.remove(blog_post.postId)
        if blog_post.postId in self.posts_map :

            update_key, update_value = {'postId': blog_post.postId}, {k: v for k, v in blog_post._asdict().items() if k not in "postId"}

            if blog_post != self.posts_map[blog_post.postId]:
                print("updating {}".format(update_key ))

                self.posts_collection.update_one(update_key,   { '$set' : update_value } )
                print("updated {} ".format(update_key))
            else:
                print("post {} unchanged".format(blog_post.postId))
        else:
            print("inserting {} ".format(blog_post.postId))
            self.posts_collection.insert_one(blog_post._asdict())
            print("inserted {} ".format(blog_post.postId))

    def delete_old_posts(self):
        for postid in self.postids:
            self.posts_collection.delete_one({'postId': postid})
            print("post {} deleted".format(postid))
